# Canvas

Canvas commands are used to create, position, and modify canvas objects. The Canvas commands need only the abaqus module to be imported; no additional modules need to be imported.

## Create layers in a viewport

### Viewport

```{eval-rst}
.. autoclass:: abaqus.Canvas.Viewport.Viewport
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Annotation features of Viewport

```{eval-rst}
.. autoclass:: abaqus.Annotation.AnnotationViewport.AnnotationViewport
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### AttributeColorMap

```{eval-rst}
.. autoclass:: abaqus.Canvas.AttributeColorMap.AttributeColorMap
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Canvas

```{eval-rst}
.. autoclass:: abaqus.Canvas.Canvas.Canvas
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Displayable

```{eval-rst}
.. autoclass:: abaqus.Canvas.Displayable.Displayable
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DrawingArea

```{eval-rst}
.. autoclass:: abaqus.Canvas.DrawingArea.DrawingArea
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Highlight

```{eval-rst}
.. automodule:: abaqus.Canvas.Highlight
    :members:
    :special-members: __init__
    :show-inheritance:
```

### ImageOptions

```{eval-rst}
.. autoclass:: abaqus.Canvas.ImageOptions.ImageOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Layer

```{eval-rst}
.. autoclass:: abaqus.Canvas.Layer.Layer
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MovieOptions

```{eval-rst}
.. autoclass:: abaqus.Canvas.MovieOptions.MovieOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ViewportBase

```{eval-rst}
.. autoclass:: abaqus.Canvas.ViewportBase.ViewportBase
    :members:
    :special-members: __init__
```
